# Exitter

This is a simple example package which helps you write an exit code for your python projects in no time.
Just import it, use 'exitter.bye()' or 'bye()' if you have used 'from exitter import bye' and call the current function in the program after using the 'exitter.bye()' or 'bye()' commands. Useful only for console-based programs.
Check out [My GitHub](https://github.com/Pranay-Chopra)